==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/CalculatedColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalculatedColumnDescription } from "./CalculatedColumnDescription";
/**
 * @hidden
 */
export let CalculatedColumnDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalculatedColumnDescriptionMetadata extends Base {
        static b(a) {
            if (CalculatedColumnDescriptionMetadata.a == null) {
                CalculatedColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalculatedColumnDescriptionMetadata.c(CalculatedColumnDescriptionMetadata.a);
            }
            if (a.k(CalculatedColumnDescriptionMetadata.a)) {
                return;
            }
            a.ab(CalculatedColumnDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            CalculatedColumnDescriptionMetadata.b(a);
            a.ad("CalculatedColumn", () => new CalculatedColumnDescription());
            a.ac("CalculatedColumn", CalculatedColumnDescriptionMetadata.a);
        }
    }
    CalculatedColumnDescriptionMetadata.$t = markType(CalculatedColumnDescriptionMetadata, 'CalculatedColumnDescriptionMetadata');
    CalculatedColumnDescriptionMetadata.a = null;
    return CalculatedColumnDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/CalculatedColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalculatedColumnDescription } from "./CalculatedColumnDescription";
/**
 * @hidden
 */
export let CalculatedColumnDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalculatedColumnDescriptionMetadata extends Base {
        static b(a) {
            if (CalculatedColumnDescriptionMetadata.a == null) {
                CalculatedColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalculatedColumnDescriptionMetadata.c(CalculatedColumnDescriptionMetadata.a);
            }
            if (a.k(CalculatedColumnDescriptionMetadata.a)) {
                return;
            }
            a.ac(CalculatedColumnDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            CalculatedColumnDescriptionMetadata.b(a);
            a.ae("CalculatedColumn", () => new CalculatedColumnDescription());
            a.ad("CalculatedColumn", CalculatedColumnDescriptionMetadata.a);
        }
    }
    CalculatedColumnDescriptionMetadata.$t = markType(CalculatedColumnDescriptionMetadata, 'CalculatedColumnDescriptionMetadata');
    CalculatedColumnDescriptionMetadata.a = null;
    return CalculatedColumnDescriptionMetadata;
})();
